@@ -6,11 +6,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <signal.h>
-#ifdef HAVE_LIBNCURSES
 #include <ncurses.h>
-#elif HAVE_LIBCURSES
-#include <curses.h>
-#endif
 #include "conf.h"
 #include "dir.h"
 #include "err.h"
